==> haskell-ipynb-0.1-45-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ipynb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ipynb
version: 0.1
id: ipynb-0.1-JMYTYv8ygqY1fVDWRv3JZt
key: ipynb-0.1-JMYTYv8ygqY1fVDWRv3JZt
license: BSD-3-Clause
copyright: Copyright (C) 2019 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
synopsis: Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.
category: Text
abi: 9b893e4a939aa52555b2dfe0b9e2d194
exposed: True
exposed-modules:
    Data.Ipynb
import-dirs: /usr/lib/ghc-8.6.5/site-local/ipynb-0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/ipynb-0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ipynb-0.1
hs-libraries: HSipynb-0.1-JMYTYv8ygqY1fVDWRv3JZt
depends:
    aeson-1.4.4.0-8EzwlpxsJYiJGXz8JVXZ1i base-4.12.0.0
    base64-bytestring-1.0.0.2-Exy4D7U0AzaE8TUydrgSTP
    bytestring-0.10.8.2 containers-0.6.0.1 text-1.2.3.1
    unordered-containers-0.2.10.0-8dby3miKFglJ7BLkdgbDGw
haddock-interfaces: /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html: /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ipynb-0.1-47-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ipynb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ipynb
version: 0.1
id: ipynb-0.1-CCYxPibgV856fZYrPaAayM
key: ipynb-0.1-CCYxPibgV856fZYrPaAayM
license: BSD-3-Clause
copyright: Copyright (C) 2019 John MacFarlane
maintainer: jgm@berkeley.edu
author: John MacFarlane
synopsis: Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.
category: Text
abi: 0b2153a6efd2712d12a83978c0ff7760
exposed: True
exposed-modules:
    Data.Ipynb
import-dirs: /usr/lib/ghc-8.6.5/site-local/ipynb-0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/ipynb-0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ipynb-0.1
hs-libraries: HSipynb-0.1-CCYxPibgV856fZYrPaAayM
depends:
    aeson-1.4.4.0-8EzwlpxsJYiJGXz8JVXZ1i base-4.12.0.0
    base64-bytestring-1.0.0.2-Exy4D7U0AzaE8TUydrgSTP
    bytestring-0.10.8.2 containers-0.6.0.1 text-1.2.3.1
    unordered-containers-0.2.10.0-8dby3miKFglJ7BLkdgbDGw
haddock-interfaces: /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html: /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
